"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const docmanager_1 = require("@jupyterlab/docmanager");
const filebrowser_1 = require("@jupyterlab/filebrowser");
const fileeditor_1 = require("@jupyterlab/fileeditor");
const panel_1 = require("./panel");
require("../style/index.css");
var CommandIDs;
(function (CommandIDs) {
    /**
     * Create a new panel to show Python Bytecode
     */
    CommandIDs.create = `pythonbytecode:create`;
})(CommandIDs || (CommandIDs = {}));
/**
 * Activate the plugin
 */
let activateByteCodePlugin = (app, browserFactory, docManager, editorTracker, palette, settingsRegistry, themeManager) => __awaiter(this, void 0, void 0, function* () {
    const { commands, serviceManager, shell } = app;
    /**
     * Create a Python bytecode panel for a given path to a Python file
     */
    const createPythonBytecodePanel = (options) => __awaiter(this, void 0, void 0, function* () {
        const settings = yield settingsRegistry.load(extension.id);
        const userSettings = settings.composite;
        yield serviceManager.ready;
        let panel = new panel_1.PythonBytecodePanel(Object.assign({ serviceManager,
            docManager,
            themeManager,
            userSettings }, options));
        yield panel.setup();
        const { panelInsertMode } = userSettings;
        const insertMode = `split-${panelInsertMode}`;
        shell.addToMainArea(panel, {
            mode: insertMode,
            ref: options.ref,
        });
        return panel;
    });
    commands.addCommand(CommandIDs.create, {
        execute: args => {
            let widget = editorTracker.currentWidget;
            if (!widget) {
                return;
            }
            let basePath = args['basePath'] ||
                args['cwd'] ||
                browserFactory.defaultBrowser.model.path;
            return createPythonBytecodePanel({
                basePath: basePath,
                path: widget.context.path,
                ref: widget.id,
            });
        },
        isEnabled: () => {
            return (editorTracker.currentWidget !== null &&
                editorTracker.currentWidget === shell.currentWidget);
        },
        isVisible: () => {
            let widget = editorTracker.currentWidget;
            return ((widget && coreutils_1.PathExt.extname(widget.context.path) === '.py') || false);
        },
        label: 'Show Python Bytecode',
    });
    app.contextMenu.addItem({
        command: CommandIDs.create,
        selector: '.jp-FileEditor',
    });
    palette.addItem({
        command: CommandIDs.create,
        category: 'File Operations',
    });
    console.log('JupyterLab extension jupyterlab-python-bytecode is activated!');
});
/**
 * Initialization data for the jupyterlab-python-bytecode extension.
 */
const extension = {
    id: 'jupyterlab-python-bytecode:plugin',
    autoStart: true,
    activate: activateByteCodePlugin,
    requires: [
        filebrowser_1.IFileBrowserFactory,
        docmanager_1.IDocumentManager,
        fileeditor_1.IEditorTracker,
        apputils_1.ICommandPalette,
        coreutils_1.ISettingRegistry,
        apputils_1.IThemeManager,
    ],
};
exports.default = extension;
