import { IClientSession, IThemeManager } from '@jupyterlab/apputils';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { ServiceManager } from '@jupyterlab/services';
import { JSONObject } from '@phosphor/coreutils';
import { Message } from '@phosphor/messaging';
import { Panel } from '@phosphor/widgets';
import { BytecodeModel } from './model';
export declare class PythonBytecodePanel extends Panel {
    constructor(options: PythonBytecodePanel.IOptions);
    setup(): Promise<any>;
    protected onCloseRequest(msg: Message): void;
    protected _setupListeners(): void;
    protected _removeListeners(): void;
    protected _getFileContent(): Promise<any>;
    protected _execute(code: string): Promise<any>;
    protected _changeTheme(): void;
    protected _handleKernelChanged(): void;
    dispose(): void;
    readonly model: BytecodeModel;
    readonly session: IClientSession;
    private _fileContext;
    private _docManager;
    private _themeManager;
    private _session;
    private _model;
    private _view;
}
export declare namespace PythonBytecodePanel {
    interface IOptions {
        /**
         * The service manager used to get a list
         * of sessions
         */
        serviceManager: ServiceManager.IManager;
        /**
         * The document manager is used to get a context
         * for the file being edited
         */
        docManager: IDocumentManager;
        /**
         * The theme manager used by the panel
         * to control the style of code highlighting
         */
        themeManager: IThemeManager;
        /**
         * Use preferences for the bytecode extension
         */
        userSettings: JSONObject;
        /**
         * Path of an existing session
         */
        path?: string;
        /**
         * The base path for a new client session
         */
        basePath?: string;
        /**
         * The name of the client session
         */
        name?: string;
        /**
         * A kernel preference.
         */
        kernelPreference?: IClientSession.IKernelPreference;
    }
}
