"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const widgets_1 = require("@phosphor/widgets");
const model_1 = require("./model");
const view_1 = require("./view");
const ICON_CLASS = 'jp-PythonIcon';
class PythonBytecodePanel extends widgets_1.Panel {
    constructor(options) {
        super();
        const count = Private.count++;
        this.id = `PythonBytecodePanel-${count}`;
        this.title.label = 'Python Bytecode';
        this.title.closable = true;
        this.title.icon = ICON_CLASS;
        let { path, name, serviceManager, docManager, themeManager, userSettings, } = options;
        let widget = docManager.findWidget(path);
        this._fileContext = docManager.contextForWidget(widget);
        this._docManager = docManager;
        this._themeManager = themeManager;
        const { kernelLanguagePreference, kernelAutoStart } = userSettings;
        this._session = new apputils_1.ClientSession({
            manager: serviceManager.sessions,
            path,
            name: name || `Python Bytecode`,
            type: 'console',
            kernelPreference: {
                language: kernelLanguagePreference,
                autoStartDefault: kernelAutoStart,
            },
        });
        this._model = new model_1.BytecodeModel();
        this._view = new view_1.BytecodeView(this._model);
        this.addWidget(this._view);
        this._session.initialize();
    }
    setup() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._session.initialize();
            yield this._session.ready;
            yield this._getFileContent();
            yield this._changeTheme();
            yield this._setupListeners();
        });
    }
    onCloseRequest(msg) {
        super.onCloseRequest(msg);
        this.dispose();
    }
    _setupListeners() {
        this._fileContext.fileChanged.connect(this._getFileContent, this);
        this._fileContext.disposed.connect(this.dispose, this);
        this._themeManager.themeChanged.connect(this._changeTheme, this);
        this._session.kernelChanged.connect(this._handleKernelChanged, this);
    }
    _removeListeners() {
        this._fileContext.fileChanged.disconnect(this._getFileContent, this);
        this._fileContext.disposed.disconnect(this.dispose, this);
        this._themeManager.themeChanged.disconnect(this._changeTheme, this);
    }
    _getFileContent() {
        return __awaiter(this, void 0, void 0, function* () {
            const path = this._fileContext.path;
            const file = yield this._docManager.services.contents.get(path);
            const msg = this._model.formatKernelMessage(file.content);
            return this._execute(msg);
        });
    }
    _execute(code) {
        return __awaiter(this, void 0, void 0, function* () {
            let future = this._session.kernel.requestExecute({ code }, true);
            future.onIOPub = this._model.handleKernelMessage;
            return future.done;
        });
    }
    _changeTheme() {
        const isLight = this._themeManager.isLight(this._themeManager.theme);
        this._model.isLight = isLight;
        this._model.notify();
    }
    _handleKernelChanged() {
        if (!this._session.kernel) {
            this.dispose();
            return;
        }
    }
    dispose() {
        console.log('dispose panel');
        // TODO: dispose session if last panel disposed?
        this._removeListeners();
        this._session.dispose();
        this._view.dispose();
        this._model.dispose();
        super.dispose();
    }
    get model() {
        return this._model;
    }
    get session() {
        return this._session;
    }
}
exports.PythonBytecodePanel = PythonBytecodePanel;
var Private;
(function (Private) {
    /**
     * Counter for new panels
     */
    Private.count = 1;
})(Private || (Private = {}));
